#
# spec file for package python-traittypes
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-traittypes
Version:        0.2.1
Release:        11.2
Summary:        Scipy trait types
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter-widgets/traittypes
Source:         https://files.pythonhosted.org/packages/source/t/traittypes/traittypes-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM gh#jupyter-widgets/traittypes#43
Patch0:         python-traittypes-remove-nose.patch
# PATCH-FIX-UPSTREAM gh#jupyter-widgets/traittypes#32
Patch1:         python-fix-nptypes.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-traitlets >= 4.2.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module traitlets >= 4.2.2}
BuildRequires:  %{python_module xarray if %python-base >= 3.10}
# /SECTION
%python_subpackages

%description
Custom trait types for scientific computing.

%prep
%autosetup -p1 -n traittypes-%{version}
sed -i '1{/^#!/d}' traittypes/tests/test_validators.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no xarray for Python 3.9 anymore
python39_ignore="--ignore traittypes/tests/test_traittypes.py"
%pytest traittypes ${$python_ignore}

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/traittypes
%{python_sitelib}/traittypes-%{version}.dist-info

%changelog
* Sun Mar  3 2024 Ben Greiner <code@bnavigator.de>
- Dejavu: Skip testing xarray on  Python 3.9
* Sun Jan 14 2024 Ben Greiner <code@bnavigator.de>
- Remove obsolete python38 skip
* Sat Mar 18 2023 Benjamin Greiner <code@bnavigator.de>
- Skip testing xarray on Python 3.8
* Sat Jan  7 2023 Ben Greiner <code@bnavigator.de>
- Add python-fix-nptypes.patch gh#jupyter-widgets/traittypes#32
- Clean specfile, no files catachall
- Use PEP517 build
* Sun Apr 11 2021 Ben Greiner <code@bnavigator.de>
- Skip python36: No pandas and numpy for Tumbleweed
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Fix BuildRequire of python-xarray for all python3 flavors
  gh#openSUSE/python-rpm-macros#66
* Thu Jul 16 2020 pgajdos@suse.com
- pytest instead of unittest, upstream prefered solution
- modified patches
  %% python-traittypes-remove-nose.patch (amended)
* Fri Jul  3 2020 pgajdos@suse.com
- switch from nose to pytest
- added patches
  fix https://github.com/jupyter-widgets/traittypes/pull/43
  + python-traittypes-remove-nose.patch
- python3 only package, xarray is actually required by
  traittypes/traittypes.py
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Disable xarray dependency and tests that require it on python2
  since xarray no longer supports python2.
* Wed Feb 20 2019 Matej Cepl <mcepl@suse.com>
- Exclude test_bad_values test while it is failing
  (gh#jupyter-widgets/traittypes#31)
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.2.1
  * Add xarray DataArray
  * Remove unused imports (pandas and xarray)
  * Add xarray Dataset
  * Allow Undefined as default
  * Refactor commond pandas trait type (DRY)
  * Add tests for SciType validators
  * Only raise error for missing dependencies on use
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
